@@ -220,7 +220,7 @@ class AutoPartition(object):
                 sleep(waittime)
         raise AutopartitionError(
             _("Failed to found partition %s after creating the partition table")
-            % device)
+            % ",".join(devices))
 
     def _createPhisicalVolumes(self, devices):
         pvCreateProg = getProgPath('/sbin/pvcreate')
