@@ -315,8 +315,10 @@ class VariableClMigrateData(UserHelper, TableVariable):
 
     def set(self, value):
         value = [
-            [x[0], {'none':''}.get(x[1],x[1]),
-            x[2],x[3]]
+            [x[0],
+            VariableClMigrateAdmin.pre_set(x[1]),
+            VariableClMigrateUserGroups.pre_set(x[2]),
+            x[3]]
             for x in value
         ]
         if len(value) == 1:
@@ -376,6 +378,10 @@ class VariableClMigrateAdmin(UserHelper, Variable):
             ("update", _("System update")),
         ]
 
+    @classmethod
+    def pre_set(cls, value):
+        return {'none':''}.get(value, value)
+
     def get_alias(self, value):
         return self.aliases.get(value, value)
 
@@ -399,6 +405,17 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
     defaultGroupList = sorted(["users", "wheel", "audio", "cdrom", "video",
                         "cdrw", "usb", "plugdev", "games", "lp", "scanner",
                         "uucp"])
+    default_value = "default"
+
+    @classmethod
+    def pre_set(cls, value):
+        """
+        Обработать значение до передачи его из таблицы в поле
+        """
+        if not any(value):
+            return [cls.default_value]
+        else:
+            return value
 
     def getDefaultGroups(self):
         return list(set(self.defaultGroupList) & set(getGroups()))
@@ -406,9 +423,16 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
     def init(self):
         self.label = _("Groups")
 
+    def process_groups(self, values):
+        for value in values:
+            if value == self.default_value:
+                for i in self.defaultGroupList:
+                    yield i
+            else:
+                yield value
+
     def set(self, value):
-        value = map(lambda x: (filter(None, x) if x and any(x)
-                               else self.getDefaultGroups()),
+        value = map(lambda x: sorted(list(set(self.process_groups(x)))),
                     value)
         return value
 
@@ -433,7 +457,8 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         """
         Available groups
         """
-        return [("", _("Default"))] + sorted([(x, x) for x in getGroups()])
+        return [(self.default_value,
+            _("Default"))] + sorted([(x, x) for x in getGroups()])
 
 
 class VariableClMigrateUserPwd(UserHelper, Variable):
